@@ -90,8 +90,8 @@ BODY_KINDS=[]
 
 # ## Util Class
 
-util_doc="""
-Util routines.
+Misc_doc="""
+Miscelaneous routines.
 
 This is a set of util routines intended for a diversity of purposes.
 
@@ -100,7 +100,7 @@ Routines included:
     get_data(file)
 """;
 
-class util(object):
+class Misc(object):
     def get_data(path):
         """
         Get the full path of the `datafile` which is one of the datafiles provided with the package.
@@ -113,7 +113,7 @@ class util(object):
             
         """
         return os.path.join(ROOTDIR,'data',path);
-util.__doc__=util_doc
+Misc.__doc__=Misc_doc
 
 # ## PrynglesCommon
 # 
@@ -137,3 +137,4 @@ from pryngles.system import *
 from pryngles.spangler import *
 from pryngles.legacy import *
 
+
